@@ -2,12 +2,12 @@ use proc_macro::TokenStream;
 use quote::{quote, ToTokens};
 
 /// Service entry-point (main)
-/// 
+///
 /// # Panics
 ///
 /// Will panic if set not on a function
 #[proc_macro_attribute]
-pub fn service(_args: TokenStream, input: TokenStream) -> TokenStream {
+pub fn svc_main(_args: TokenStream, input: TokenStream) -> TokenStream {
     let mut item: syn::Item = syn::parse(input).expect("Invalid input");
     let fn_item = match &mut item {
         syn::Item::Fn(fn_item) => fn_item,
@@ -28,7 +28,7 @@ pub fn service(_args: TokenStream, input: TokenStream) -> TokenStream {
         fn main() -> eva_common::EResult<()> {
             eva_sdk::service::svc_launch(eva_service_main)
         }
-        async fn eva_service_main(initial: eva_sdk::prelude::Initial) -> eva_common::EResult<()>
+        async fn eva_service_main(mut initial: eva_sdk::prelude::Initial) -> eva_common::EResult<()>
             #block
     };
     f.into_token_stream().into()
